/**/
/*******************************************************************

		translate.c

	This file contains all routines that perform coordinate
	translation.  These include rotation and unit system
	conversion.

	Included functions are:

	*  rotate()
	*  radToDeg()
	*  degToRad()
        *  applyVec()
	( * indicates function is declared as an extern )

*******************************************************************/

#include <stdio.h>
#include <math.h>


#include "miscMath.h"
/* #include "plate.h" */
/* #include "motor.h" */ 
#include "translate.h"


/*
		rotate

	Take the coordinate pointed to by the first argument
	and rotate it about the system origin by the angle
	given in the second argument.  The original coordinate
	is over-written.
*/

void rotate( point *pCoords, double angle)

{
   double r;		/*  radius from origin to target coord */ 
   double phi1;		/*  original angle of target */
   double phi2;		/*  new angle of target */

   double x = pCoords->x;
   double y = pCoords->y;

   r = sqrt( (x * x) +  (y * y) );

   if( ( x != 0 ) || ( y != 0 ) ){
      phi1 = atan2( y, x );
   }
   else{
      phi1 = 0.0;
   }

   phi2 = phi1 + angle;

   /* overwrite the originals */

   pCoords->x = nint( r * cos( phi2 ) );
   pCoords->y = nint( r * sin( phi2 ) );
}


/*
		radToDeg

   Convert the supplied angle in radians to degrees and
   return the new value.
*/

double radToDeg( double angle )

{
   return( ( angle / TWOPI ) * 360.0 );
}


/*
		degToRad

   Convert the supplied angle in degrees to radians and
   return the new value.
*/

double degToRad( double angle )

{
   return( (angle / 360.0) * TWOPI );
}



/*
		applyVec

   Apply a vector translation to a point.
*/

void applyVec( point *thePoint, point *vector, int direction )

{
   if( direction == NORMAL ){
      thePoint->x += vector->x;
      thePoint->y += vector->y;
   }
   else{ /* direction == INVERT */
      thePoint->x -= vector->x;
      thePoint->y -= vector->y;
   }
}
